@@ -1,9 +1,9 @@
-from time import sleep
-import telnetlib
 import logging
 import sys
-import six
+from time import sleep
 
+import six
+from jnpr.junos.transport._telnetlib import telnetlib
 from jnpr.junos.transport.tty import Terminal
 
 logger = logging.getLogger("jnpr.junos.tty_telnet")
