@@ -1,9 +1,10 @@
 # stdlib
 from __future__ import print_function
+
 import hashlib
 import re
-from os import path
 import sys
+from os import path
 
 try:
     # Python 3.x
@@ -13,18 +14,18 @@ except ImportError:
     from urlparse import urlparse
 
 # 3rd-party modules
-from lxml.builder import E
-from lxml import etree
+from jnpr.junos import jxml as JXML
 
 # local modules
 from jnpr.junos.decorators import timeoutDecorator
-from jnpr.junos.utils.util import Util
-from jnpr.junos.utils.scp import SCP
+from jnpr.junos.exception import RpcError, RpcTimeoutError, SwRollbackError
 from jnpr.junos.utils.ftp import FTP
+from jnpr.junos.utils.scp import SCP
 from jnpr.junos.utils.start_shell import StartShell
-from jnpr.junos.exception import SwRollbackError, RpcTimeoutError, RpcError
+from jnpr.junos.utils.util import Util
+from lxml import etree
+from lxml.builder import E
 from ncclient.xml_ import NCElement
-from jnpr.junos import jxml as JXML
 
 """
 Software Installation Utilities
@@ -413,7 +414,7 @@ class SW(Util):
             # request-shell-execute rpc is not available for <14.1
             with StartShell(self._dev) as ss:
                 ss.run("cli", "> ", timeout=5)
-                if ss.run("request routing-engine " "login other-routing-engine")[0]:
+                if ss.run("request routing-engine login other-routing-engine")[0]:
                     # depending on user permission, prompt will go to either
                     # cli or shell, below line of code prompt will finally end
                     # up in cli mode
@@ -423,12 +424,12 @@ class SW(Util):
                     ss.run("exit")
                 else:
                     self.log(
-                        "Requirement FAILED: Not able run " '"show system switchover"'
+                        'Requirement FAILED: Not able run "show system switchover"'
                     )
                     return False
         gres_status = re.search(r"Graceful switchover: (\w+)", output, re.I)
         if not (gres_status is not None and gres_status.group(1).lower() == "on"):
-            self.log("Requirement FAILED: Graceful switchover status " "is not On")
+            self.log("Requirement FAILED: Graceful switchover status is not On")
             return False
         self.log("Graceful switchover status is On")
         return True
@@ -465,7 +466,7 @@ class SW(Util):
             },
         )
         if conf.find("chassis/redundancy/graceful-switchover") is None:
-            self.log("Requirement FAILED: GRES is not Enabled " "in configuration")
+            self.log("Requirement FAILED: GRES is not Enabled in configuration")
             return False
         self.log("Checking commit synchronize configuration")
         conf = self._dev.rpc.get_config(
@@ -487,8 +488,7 @@ class SW(Util):
         )
         if conf.find("system/commit/synchronize") is None:
             self.log(
-                "Requirement FAILED: commit synchronize is not "
-                "Enabled in configuration"
+                "Requirement FAILED: commit synchronize is not Enabled in configuration"
             )
             return False
         self.log("Checking NSR configuration")
@@ -709,7 +709,7 @@ class SW(Util):
         all_re=True,
         member_id=None,
         vmhost=False,
-        **kwargs
+        **kwargs,
     ):
         """
         Performs the complete installation of the **package** that includes the
@@ -757,7 +757,7 @@ class SW(Util):
                       * MX virtual-chassis
 
         You can get a progress report on this process by providing a
-        **progress** callback.
+        ``progress`` callback.
 
         .. note:: You will need to invoke the :meth:`reboot` method explicitly
                    to reboot the device.
@@ -865,9 +865,10 @@ class SW(Util):
           (Optional) A boolean indicating if this is a software update of the
           vhmhost. The default is ``vmhost=False``.
 
-        :param kwargs **kwargs:
-          (Optional) Additional keyword arguments are passed through to the
-          "package add" RPC.
+        :param dict kwargs:
+          (Optional) Additional keyword arguments passed through to the
+          ``package add`` RPC. Use dash-to-underscore conversion for RPC
+          parameters when passing them in via Python kwargs.
 
         :returns: tuple(<status>, <msg>)
             * status : ``True`` when the installation is successful and ``False`` otherwise
@@ -984,11 +985,17 @@ class SW(Util):
                     kwargs.update({"no_validate": True})
 
             if issu is True:
+                if validate is False:  # To Check validation is False
+                    # Need to pass the no_validate option via kwargs
+                    kwargs.update({"no_validate": True})
                 _progress("ISSU: installing software ... please be patient ...")
                 return self.pkgaddISSU(
                     remote_package, vmhost=vmhost, dev_timeout=timeout, **kwargs
                 )
             elif nssu is True:
+                if validate is False:
+                    # Need to pass the no_validate option via kwargs
+                    kwargs.update({"no_validate": True})
                 _progress("NSSU: installing software ... please be patient ...")
                 return self.pkgaddNSSU(remote_package, dev_timeout=timeout, **kwargs)
             elif member_id is not None:
@@ -1012,7 +1019,7 @@ class SW(Util):
                                 vmhost=vmhost,
                                 member=vc_id,
                                 dev_timeout=timeout,
-                                **kwargs
+                                **kwargs,
                             )
                             ok = ok[0] and bool_ret, ok[1] + "\n" + msg
                     return ok
@@ -1033,7 +1040,8 @@ class SW(Util):
                         for x in self._RE_list
                         if re.search(r"(\d+)", x)
                     ]
-                    vc_members.remove(self.dev.facts["vc_master"])
+                    if self.dev.facts["vc_master"] in vc_members:
+                        vc_members.remove(self.dev.facts["vc_master"])
                     vc_members.insert(len(vc_members), self.dev.facts["vc_master"])
                     for vc_id in vc_members:
                         _progress(
@@ -1045,29 +1053,40 @@ class SW(Util):
                             vmhost=vmhost,
                             member=vc_id,
                             dev_timeout=timeout,
-                            **kwargs
+                            **kwargs,
                         )
                         ok = ok[0] and bool_ret, ok[1] + "\n" + msg
                     return ok
                 else:
-                    # then this is a device with two RE that supports the "re0"
-                    # and "re1" options to the command (M, MX tested only)
-                    _progress("installing software on RE0 ... please be patient ...")
-                    ok = self.pkgadd(
-                        remote_package,
-                        vmhost=vmhost,
-                        re0=True,
-                        dev_timeout=timeout,
-                        **kwargs
-                    )
-                    _progress("installing software on RE1 ... please be patient ...")
-                    bool_ret, msg = self.pkgadd(
-                        remote_package,
-                        vmhost=vmhost,
-                        re1=True,
-                        dev_timeout=timeout,
-                        **kwargs
-                    )
+                    # For Dual RE device re0/re1 is not required
+                    if self._dev.facts["_is_linux"]:
+                        _progress("installing software ... please be patient ...")
+                        ok = self.pkgadd(
+                            remote_package, vmhost=vmhost, dev_timeout=timeout, **kwargs
+                        )
+                    else:
+                        # then this is a device with two RE that supports the "re0"
+                        # and "re1" options to the command (M, MX tested only)
+                        _progress(
+                            "installing software on RE0 ... please be patient ..."
+                        )
+                        ok = self.pkgadd(
+                            remote_package,
+                            vmhost=vmhost,
+                            re0=True,
+                            dev_timeout=timeout,
+                            **kwargs,
+                        )
+                        _progress(
+                            "installing software on RE1 ... please be patient ..."
+                        )
+                        bool_ret, msg = self.pkgadd(
+                            remote_package,
+                            vmhost=vmhost,
+                            re1=True,
+                            dev_timeout=timeout,
+                            **kwargs,
+                        )
                     ok = ok[0] and bool_ret, ok[1] + "\n" + msg
                     return ok
 
@@ -1131,13 +1150,12 @@ class SW(Util):
             elif self._mixed_VC is True:
                 cmd.append(E("all-members"))
         elif (
-            self._multi_VC_nsync is True
-            or self._multi_VC is True
-            and member_id is not None
-        ):
+            self._multi_VC_nsync is True or self._multi_VC is True
+        ) and member_id is not None:
             cmd.append(E("member", str(member_id)))
         if in_min >= 0 and at is None:
-            cmd.append(E("in", str(in_min)))
+            if vmhost is not True:
+                cmd.append(E("in", str(in_min)))
         elif at is not None:
             cmd.append(E("at", str(at)))
         try:
@@ -1209,9 +1227,21 @@ class SW(Util):
         :returns:
             * reboot message (string) if command successful
         """
+
+        if (
+            self._multi_VC_nsync is True or self._multi_VC is True
+        ) and member_id is not None:
+            vc_members = [
+                re.search(r"(\d+)", x).group(1)
+                for x in self._RE_list
+                if re.search(r"(\d+)", x)
+            ]
+            vc_members.remove(self.dev.facts["vc_master"])
+            vc_members.insert(len(vc_members), self.dev.facts["vc_master"])
+
         if self._dev.facts["_is_linux"]:
             if on_node is None:
-                cmd = E("request-shutdown-reboot")
+                cmd = E("request-system-reboot")
             else:
                 cmd = E("request-node-reboot")
                 cmd.append(E("node", on_node))
@@ -1221,9 +1251,14 @@ class SW(Util):
             cmd = E("request-reboot")
 
         try:
-            return self._system_operation(
-                cmd, in_min, at, all_re, other_re, vmhost, member_id
-            )
+            if member_id is not None:
+                for m_id in member_id:
+                    if m_id in vc_members:
+                        return self._system_operation(
+                            cmd, in_min, at, all_re, other_re, vmhost, member_id=m_id
+                        )
+            else:
+                return self._system_operation(cmd, in_min, at, all_re, other_re, vmhost)
         except RpcTimeoutError as err:
             raise err
         except Exception as err:
@@ -1232,7 +1267,9 @@ class SW(Util):
     # -------------------------------------------------------------------------
     # poweroff - system shutdown
     # -------------------------------------------------------------------------
-    def poweroff(self, in_min=0, at=None, on_node=None, all_re=True, other_re=False):
+    def poweroff(
+        self, in_min=0, at=None, on_node=None, all_re=True, other_re=False, vmhost=False
+    ):
         """
         Perform a system shutdown, with optional delay (in minutes) .
 
@@ -1254,6 +1291,8 @@ class SW(Util):
         :param str other_re: If the system has dual Routing Engines and this option is C(true),
             then the action is performed on the other REs in the system.
 
+        :param str vmhost: If the device is vmhost device then the shutdown will be performed on the device
+
         :returns:
             * power-off message (string) if command successful
 
@@ -1267,12 +1306,13 @@ class SW(Util):
             else:
                 cmd = E("request-node-power-off")
                 cmd.append(E("node", on_node))
+        elif vmhost is True:
+            cmd = E("request-vmhost-poweroff")
+            all_re = False
         else:
             cmd = E("request-power-off")
         try:
-            return self._system_operation(
-                cmd, in_min, at, all_re, other_re, vmhost=False
-            )
+            return self._system_operation(cmd, in_min, at, all_re, other_re, vmhost)
         except Exception as err:
             if err.rsp.findtext(".//error-severity") != "warning":
                 raise err
