@@ -1,5 +1,5 @@
-VERSION = "2.7.3"
-DATE = "2025-Feb-14"
+VERSION = "2.7.6"
+DATE = "2026-Jan-16"
 
 # Augment with the internal version if present
 try:
